==> sms_message-1.0.4.tar.gz: sms_message/sms-android/app/src/main/java/com/sms/sendmessage/SampleService.java <==
package com.sms.sendmessage;

import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.IBinder;
import android.os.PowerManager;

import androidx.annotation.Nullable;
import androidx.core.app.NotificationCompat;

import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;

public class SampleService extends Service {

    private static final int NOTIF_ID = 1;
    public static final String NOTIF_CHANNEL_ID = "Channel_Id";

    private int mStartMode;
    private IBinder mBinder;
    private boolean mAllowRebind;

    private ScheduledExecutorService scheduledExecutorService;

    private PowerManager.WakeLock wakeLock;

    private void startForegroundService() {
        Intent notificationIntent = new Intent(this, MainActivity.class);

        PendingIntent pendingIntent = PendingIntent.getActivity(this, 0,
                notificationIntent, PendingIntent.FLAG_IMMUTABLE);

        startForeground(NOTIF_ID, new NotificationCompat.Builder(this, NOTIF_CHANNEL_ID)
                .setOngoing(true)
                .setSmallIcon(R.drawable.ic_notification)
                .setContentTitle(getString(R.string.app_name))
                .setContentText("Service is running in the background")
                .setContentIntent(pendingIntent)
                .build());
    }

    @Override
    public void onCreate() {
      startForegroundService();

      // Create WakeLock with FLAG_KEEP_SCREEN_ON to keep device always on.
      PowerManager powerManager = (PowerManager) getSystemService(Context.POWER_SERVICE);
      wakeLock = powerManager.newWakeLock(PowerManager.PARTIAL_WAKE_LOCK, "SampleService:WakeLock");
      wakeLock.acquire();
    }

    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {
        startHandlerThread();
        startForegroundService();
        return mStartMode;
    }

    @Nullable
    @Override
    public IBinder onBind(Intent intent) { return mBinder; }

    @Override
    public boolean onUnbind(Intent intent) {
        return mAllowRebind;
    }

    @Override
    public void onRebind(Intent intent) {}

    @Override
    public void onDestroy() {
        if (scheduledExecutorService != null) {
            scheduledExecutorService.shutdownNow();
        }
        // Release WakeLock Service.
        if (wakeLock != null && wakeLock.isHeld()) {
          wakeLock.release();
        }
    }

  public void startHandlerThread() {
    scheduledExecutorService = Executors.newSingleThreadScheduledExecutor();
    scheduledExecutorService.scheduleAtFixedRate(new Runnable() {
      @Override
      public void run() {
        try {
          MainActivity.callAPI();
        } catch (Exception e) {
          e.printStackTrace();
          // Handle the exception as needed
        }
      }
    }, 0, 5, TimeUnit.SECONDS);
  }
}

==> sms_message-1.0.6.tar.gz: sms_message/sms-android/app/src/main/java/com/sms/sendmessage/SampleService.java <==
package com.sms.sendmessage;

import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.IBinder;
import android.os.PowerManager;

import androidx.annotation.Nullable;
import androidx.core.app.NotificationCompat;

import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;

public class SampleService extends Service {

    private static final int NOTIF_ID = 1;
    public static final String NOTIF_CHANNEL_ID = "Channel_Id";

    private int mStartMode;
    private IBinder mBinder;
    private boolean mAllowRebind;

    private ScheduledExecutorService scheduledExecutorService;

    private PowerManager.WakeLock wakeLock;

    private void startForegroundService() {
        Intent notificationIntent = new Intent(this, MainActivity.class);

        PendingIntent pendingIntent = PendingIntent.getActivity(this, 0,
                notificationIntent, PendingIntent.FLAG_IMMUTABLE);

        startForeground(NOTIF_ID, new NotificationCompat.Builder(this, NOTIF_CHANNEL_ID)
                .setOngoing(true)
                .setSmallIcon(R.drawable.ic_notification)
                .setContentTitle(getString(R.string.app_name))
                .setContentText("Service is running in the background")
                .setContentIntent(pendingIntent)
                .build());
    }

    @Override
    public void onCreate() {
      startForegroundService();

      // Create WakeLock with FLAG_KEEP_SCREEN_ON to keep device always on.
      PowerManager powerManager = (PowerManager) getSystemService(Context.POWER_SERVICE);
      wakeLock = powerManager.newWakeLock(PowerManager.PARTIAL_WAKE_LOCK, "SampleService:WakeLock");
      wakeLock.acquire();
    }

    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {
        startHandlerThread();
        startForegroundService();
        return mStartMode;
    }

    @Nullable
    @Override
    public IBinder onBind(Intent intent) { return mBinder; }

    @Override
    public boolean onUnbind(Intent intent) {
        return mAllowRebind;
    }

    @Override
    public void onRebind(Intent intent) {}

    @Override
    public void onDestroy() {
        if (scheduledExecutorService != null) {
            scheduledExecutorService.shutdownNow();
        }
        // Release WakeLock Service.
        if (wakeLock != null && wakeLock.isHeld()) {
          wakeLock.release();
        }
    }

  public void startHandlerThread() {
    scheduledExecutorService = Executors.newSingleThreadScheduledExecutor();
    scheduledExecutorService.scheduleAtFixedRate(new Runnable() {
      @Override
      public void run() {
        try {
          MainActivity.callAPI(SampleService.this);
        } catch (Exception e) {
          e.printStackTrace();
          // Handle the exception as needed
        }
      }
    }, 0, 5, TimeUnit.SECONDS);
  }
}
